@@ -2,7 +2,7 @@
 use strict;
 $|++;
 
-my $VERSION = '1.02';
+my $VERSION = '1.06';
 
 #----------------------------------------------------------------------------
 
@@ -69,16 +69,18 @@ my %groups = (
 # -------------------------------------
 # Program
 
-GetOptions(\%options, 'build', 'release') or die "Usage: $0 [--build] [--release]\n";
+GetOptions(\%options, 'local', 'build', 'release') or die "Usage: $0 [--local] [--build] [--release]\n";
 
 my $base = dirname($0);
 chdir($base);
 #print "dir=$base\n";
 
-my $mech = WWW::Mechanize->new();
-my $source = 'http://stats.cpantesters.org/stats/cpan100.csv';
-my $target = basename($source);
-$mech->mirror($source,$target);
+unless($options{local}) {
+    my $mech = WWW::Mechanize->new();
+    my $source = 'http://stats.cpantesters.org/stats/cpan100.csv';
+    my $target = basename($source);
+    $mech->mirror($source,$target);
+}
 
 # read old file
 my $inx = 0;
